@@ -1,8 +1,5 @@
-import contextlib
-import socket
 import traceback
 import typing as t
-from concurrent import futures
 from operator import attrgetter
 
 import grpc
@@ -164,7 +161,6 @@ try:
         bind_address: str,
         add_services: t.Callable[[grpc.aio.Server], None],
         reflection_services: t.Iterable[str] = tuple(),
-        reuse_port: bool = False,
         current_process: int = 1,
         total_processes: int = 1,
     ):
@@ -173,13 +169,10 @@ try:
         Args:
             bind_address: Complete address consisting of hostname and port (e.g., `127.0.0.1:8000`)
             add_services: Function to inject the gRPC services into the server instance.
-            reuse_port: If using multiple processes, the port has to be reused.
             current_process: Number of current process.
             total_processes: Total number of spawned processes.
         """
-        server = grpc.aio.server(
-            options=(("grpc.aio.so_reuseport", 1 if reuse_port else 0),),
-        )
+        server = grpc.aio.server()
         add_services(server)
 
         if reflection_services:
@@ -200,8 +193,7 @@ try:
         host: str,
         port: int,
         add_services: t.Callable[[grpc.aio.Server], None],
-        processes: int,
-        reuse_port: bool = False,
+        processes: int = 1,
         reflection_services: t.Iterable[str] = tuple(),
     ):
         """Serve one or multiple gRPC services, optionally using multiprocessing.
@@ -212,32 +204,23 @@ try:
                 Use `0` to let the server determine an open port.
             add_services: Function to inject the gRPC services into the server instance.
             processes: Number of workers.
-            reuse_port: On Linux systems, the OS can automatically perform load balancing.
-                If true, the option `SO_REUSEPORT` will be set.
 
         Raises:
             ValueError: If `processes < 0` is given.
         """
 
-        reuse_port = reuse_port and (processes == 1)
-
         if processes == 1:
-            with _reserve_port(port) as actual_port:
-                bind_addr = f"{host}:{actual_port}"
-                print(f"Connect to 'ipv4:{bind_addr}'.")
+            bind_addr = f"{host}:{port}"
+            print(f"Connect to 'ipv4:{bind_addr}'.")
 
-                await _serve_single(bind_addr, add_services, reflection_services)
+            await _serve_single(bind_addr, add_services, reflection_services)
         else:
-            socks = []
             workers = []
-            addresses = set()
+            addresses = []
 
             for i, port in enumerate(range(port, port + processes)):
-                sock = _open_port(port)
-                socks.append(socks)
-                actual_port = _port_number(sock)
-                bind_addr = f"{host}:{actual_port}"
-                addresses.add(bind_addr)
+                bind_addr = f"{host}:{port}"
+                addresses.append(bind_addr)
 
                 worker = mp.Process(
                     target=_serve_single,
@@ -245,7 +228,6 @@ try:
                         bind_addr,
                         add_services,
                         reflection_services,
-                        reuse_port,
                         i + 1,
                         processes,
                     ),
@@ -259,53 +241,6 @@ try:
             for worker in workers:
                 await worker.join()
 
-            for sock in socks:
-                _close_port(sock)
-
-    @contextlib.contextmanager
-    def _reserve_port(
-        port: int = 0, reuse_port: bool = False
-    ) -> t.Generator[int, None, None]:
-        """Find and reserve a port for all subprocesses to use.
-
-        Args:
-            port: Desired port. If `0`, the method will automatically determine a free port.
-            reuse_port: If using multiple processes, set this to `True`.
-                Only affects multiprocessing, not multithreading.
-
-        Yields:
-            Port that has been reserved
-
-        Raises:
-            RuntimeError: If the port could not be reused
-        """
-
-        sock = _open_port(port, reuse_port)
-
-        try:
-            yield _port_number(sock)
-        finally:
-            _close_port(sock)
-
-    def _close_port(sock: socket.socket) -> None:
-        sock.close()
-
-    def _port_number(sock: socket.socket) -> int:
-        return sock.getsockname()[1]
-
-    def _open_port(port: int = 0, reuse_port: bool = False) -> socket.socket:
-        sock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-
-        if reuse_port:
-            sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEPORT, 1)
-
-            if sock.getsockopt(socket.SOL_SOCKET, socket.SO_REUSEPORT) == 0:
-                raise RuntimeError("Failed to set SO_REUSEPORT.")
-
-        sock.bind(("", port))
-
-        return sock
-
 
 except ImportError:
     pass
